#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2011  Marek Marczykowski <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

# enable python3 by default
%bcond_without python3

# python2 is not available on RHEL > 7 and not needed on Fedora > 28
%if 0%{?rhel} > 7 || 0%{?fedora} > 28
# disable python2 by default
%bcond_with python2
%else
%bcond_without python2
%endif


Name:		qubes-gpg-split-dom0
Version:	2.0.55
Release:	1%{dist}
Summary:    Qubes policy for gpg split

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

BuildRequires: make
%if %{with python2}
BuildRequires: python-setuptools
BuildRequires: python2-rpm-macros
%endif
%if %{with python3}
BuildRequires: python3-rpm-macros
BuildRequires: python3-setuptools
BuildRequires: python3-devel
%endif
Requires:	gpg

Source0: qubes-gpg-split-%{version}.tar.gz

%description

%prep
%setup -q -n qubes-gpg-split-%{version}

%install
rm -rf $RPM_BUILD_ROOT
install -m 0664 -D qubes.Gpg.policy $RPM_BUILD_ROOT/etc/qubes-rpc/policy/qubes.Gpg
install -m 0664 -D qubes.GpgImportKey.policy $RPM_BUILD_ROOT/etc/qubes-rpc/policy/qubes.GpgImportKey
%{?with_python2:make -C tests install-dom0-py2 DESTDIR=$RPM_BUILD_ROOT PYTHON2=%{__python2}}
%{?with_python3:make -C tests install-dom0-py3 DESTDIR=$RPM_BUILD_ROOT PYTHON2=%{__python3}}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%config(noreplace) %attr(0664,root,qubes) /etc/qubes-rpc/policy/qubes.Gpg
%config(noreplace) %attr(0664,root,qubes) /etc/qubes-rpc/policy/qubes.GpgImportKey
%if %{with python2}
%dir %{python2_sitelib}/splitgpg-*.egg-info
%{python2_sitelib}/splitgpg-*.egg-info/*
%{python2_sitelib}/splitgpg
%endif
%if %{with python3}
%dir %{python3_sitelib}/splitgpg-*.egg-info
%{python3_sitelib}/splitgpg-*.egg-info/*
%{python3_sitelib}/splitgpg
%endif

%changelog
* Sun Dec 12 2021 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-app-linux-split-gpg.git

* Sun Dec 12 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3ad9aee
- version 2.0.55

* Sun Dec 12 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5fe4133
- Do not use fancy unicode quotes

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - e280dc0
- Avoid mishandling empty strings

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 47ac258
- Consolidate redundant case branches

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 0cbea15
- Use bash's [[ consistently

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - df81022
- Convert --detach into --detach-sign

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 10f7156
- Fix some bugs in the wrapper script

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 38e8081
- Require arguments to be printable UTF-8

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 92a4e6a
- Never permute arguments and options

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - a0b541d
- Server: reduce getopt_long(3)’s attack surface

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 5de8cde
- Reject abbreviated long options

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 30c61d3
- Fix short option handling in wrapper script

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 358e897
- Better error message if GPG tries to read a password

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - efc437b
- Do not allow remote qube to control argv[0] of gpg

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 8806da6
- Remove options already ignored in wrapper script

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - ed876f4
- Fix some bugs in the wrapper script

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 54c9e65
- Remove ‘--rfc1991’

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - f614220
- Add trailing newline in error message

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 1cf98b7
- Trivial client cleanup

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 8c3a4a0
- Fix quoting bug

* Tue Nov 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 353e827
- version 2.0.54

* Tue Nov 02 2021 deeplow <deeplower@protonmail.com> - 13a9caa
- tests: remove deprecated enigmail HACK & tb restart

* Tue Nov 02 2021 deeplow <deeplower@protonmail.com> - 3458bc5
- tests: tb add PGP key to acct via user.js

* Wed Oct 27 2021 deeplow <deeplower@protonmail.com> - b3b72ed
- tests: retry "enter imap password" on fail

* Wed Oct 27 2021 deeplow <deeplower@protonmail.com> - 5f71ba8
- tests: support windows with role 'frame' or 'dialog'

* Wed Oct 27 2021 Alyssa Ross <hi@alyssa.is> - f48ef30
- Make fd path replacement length check clearer

* Wed Oct 27 2021 Alyssa Ross <hi@alyssa.is> - 089d1fb
- Fix off-by-one in fd path replacement

* Fri Oct 22 2021 deeplow <deeplower@protonmail.com> - 52cc3cc
- tests: improve resilience of OpenPGP button click

* Fri Oct 22 2021 deeplow <deeplower@protonmail.com> - f03ce50
- tests: check mail manually instead

* Tue Oct 19 2021 deeplow <deeplower@protonmail.com> - cb2ba73
- tests: make thunderbird user.js dynamically generated

* Mon Oct 18 2021 deeplow <deeplower@protonmail.com> - 471dd95
- tests: tb fix OpenPGP opening in tb91+

* Mon Oct 18 2021 deeplow <deeplower@protonmail.com> - c15b563
- tests: remove deprecated tb OpenPGP message code

* Fri Oct 15 2021 deeplow <deeplower@protonmail.com> - bc23eeb
- tests: more fixes for tb 91+

* Fri Oct 15 2021 deeplow <deeplower@protonmail.com> - b5a3446
- tests: fix bug where arguments were missing a space

* Fri Oct 15 2021 deeplow <deeplower@protonmail.com> - 19cbfe1
- tests: autotype IMAP password

* Thu Oct 14 2021 deeplow <deeplower@protonmail.com> - 8709c2d
- tests: remove autoconf and local account setup code

* Thu Oct 14 2021 deeplow <deeplower@protonmail.com> - 0069ad3
- tests: thunderbird use user.js for default profile

* Tue Oct 12 2021 deeplow <deeplower@protonmail.com> - 3c1b9ac
- test: add IMAP server as tb 91+ removed movemail

* Thu Sep 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6ddc1db
- version 2.0.53

* Tue Sep 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f3f72b9
- tests: option arguments parsing

* Tue Sep 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cd4e229
- tests: include stderr in the failure message

* Tue Sep 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c3301ff
- Add --display option to the parser

* Tue Sep 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 819f3bb
- Fix forbidden option reporting

* Tue Sep 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - dd0ae88
- Add --default-recipient option to the parser

* Mon Sep 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 678a1b2
- Remove duplicated --fixed-list-mode

* Mon Sep 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3c8da0d
- Fix --with-colons declaration

* Mon Sep 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d0d8a42
- Properly handle gpg's command options

* Mon Sep 06 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c1b0e14
- Correctly mark --s2k-* options as requiring an argument

* Thu Sep 02 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 92835aa
- Tighten up parsing of file descriptors

* Thu Sep 02 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6a00456
- version 2.0.52

